@@ -1,5 +1,3 @@
-import io
-
 from ansiblemetrics import metrics_extractor
 from .base import BaseMetricsExtractor
 from repominer.filters import is_ansible_file
@@ -17,9 +15,9 @@ class AnsibleMetricsExtractor(BaseMetricsExtractor):
         :return: a dictionary {string: float} with metrics. If an error occurs, return an empty dictionary
         """
         try:
-            return metrics_extractor.extract_all(io.StringIO(script))
+            return metrics_extractor.extract_all(script)
         except (TypeError, ValueError):
-            return {}
+            return dict()
 
     def ignore_file(self, path_to_file: str, content: str = None):
         return not is_ansible_file(path_to_file)
